@@ -12,8 +12,8 @@
 #define MIN(a, b) ((a) < (b) ? (a) : (b))
 #endif
 
-double jaro_winkler(const JFISH_UNICODE *str1, int len1, const JFISH_UNICODE *str2, int len2, int long_tolerance);
-double jaro_distance(const JFISH_UNICODE *str1, int len1, const JFISH_UNICODE *str2, int len2);
+double jaro_winkler_similarity(const JFISH_UNICODE *str1, int len1, const JFISH_UNICODE *str2, int len2, int long_tolerance);
+double jaro_similarity(const JFISH_UNICODE *str1, int len1, const JFISH_UNICODE *str2, int len2);
 
 size_t hamming_distance(const JFISH_UNICODE *str1, int len1,
         const JFISH_UNICODE *str2, int len2);
