@@ -28,7 +28,6 @@ char* metaphone(const char *str)
         if ((c == 'k' && next == 'n') ||
             (c == 'g' && next == 'n') ||
             (c == 'p' && next == 'n') ||
-            (c == 'a' && next == 'c') ||
             (c == 'w' && next == 'r') ||
             (c == 'a' && next == 'e')) {
             str++;
@@ -88,11 +87,14 @@ char* metaphone(const char *str)
         case 'g':
             if (next == 'i' || next == 'e' || next == 'y') {
                 *r++ = 'J';
-            } else if(next != 'h' && next != 'n') {
-                *r++ = 'K';
             } else if(next == 'h' && !(ISVOWEL(nextnext))) {
                 s++;
                 next = tolower(*(s + 1));
+            } else if(next == 'n' && !nextnext) {
+                s++;
+                next = tolower(*(s + 1));
+            } else {
+                *r++ = 'K';
             }
             break;
         case 'h':
@@ -160,9 +162,7 @@ char* metaphone(const char *str)
         case 'w':
             if (s == str && next == 'h') {
                 next = tolower(*(++s + 1));
-                if (ISVOWEL(next) || next == 0) {
-                    *r++ = 'W';
-                }
+                *r++ = 'W';
             } else if (ISVOWEL(next)) {
                 *r++ = 'W';
             }
